# coding: utf-8

"""
    Klavis AI (https://www.klavis.ai)

    Klavis AI - Open Source MCP Integrations for AI Applications

    The version of the OpenAPI document: 0.1.0
    Contact: connect@klavis.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class WhiteLabelServerName(str, Enum):
    """
    WhiteLabelServerName
    """

    """
    allowed enum values
    """
    SLACK = 'Slack'
    SUPABASE = 'Supabase'
    NOTION = 'Notion'
    GITHUB = 'GitHub'
    JIRA = 'Jira'
    WORDPRESS = 'WordPress'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WhiteLabelServerName from a JSON string"""
        return cls(json.loads(json_str))


