# coding: utf-8

"""
    Klavis AI (https://www.klavis.ai)

    Klavis AI - Open Source MCP Integrations for AI Applications

    The version of the OpenAPI document: 0.1.0
    Contact: connect@klavis.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ServerName(str, Enum):
    """
    ServerName
    """

    """
    allowed enum values
    """
    MARKDOWN2DOC = 'Markdown2doc'
    SLACK = 'Slack'
    SUPABASE = 'Supabase'
    POSTGRES = 'Postgres'
    YOUTUBE = 'YouTube'
    DOC2MARKDOWN = 'Doc2markdown'
    KLAVIS_REPORTGEN = 'Klavis ReportGen'
    RESEND = 'Resend'
    DISCORD = 'Discord'
    FIRECRAWL_WEB_SEARCH = 'Firecrawl Web Search'
    GITHUB = 'GitHub'
    FIRECRAWL_DEEP_RESEARCH = 'Firecrawl Deep Research'
    JIRA = 'Jira'
    WORDPRESS = 'WordPress'
    NOTION = 'Notion'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ServerName from a JSON string"""
        return cls(json.loads(json_str))


