# coding: utf-8

"""
    Klavis AI (https://www.klavis.ai)

    Klavis AI - Open Source MCP Integrations for AI Applications

    The version of the OpenAPI document: 0.1.0
    Contact: connect@klavis.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301
from pathlib import Path

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "klavis"
VERSION = "0.0.8"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name=NAME,
    version=VERSION,
    description="Klavis AI (https://www.klavis.ai)",
    author="Klavis AI",
    author_email="connect@klavis.ai",
    url="",
    keywords=["MCP", "AI", "LLM", "Klavis", "Klavis AI"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description=long_description,
    package_data={"klavis": ["py.typed"]},
)